# yaqd-control

[![PyPI](https://img.shields.io/pypi/v/yaqd-control)](https://pypi.org/project/yaqd-control)
[![Conda](https://img.shields.io/conda/vn/conda-forge/yaqd-control)](https://anaconda.org/conda-forge/yaqd-control)
[![yaq](https://img.shields.io/badge/framework-yaq-orange)](https://yaq.fyi/)
[![black](https://img.shields.io/badge/code--style-black-black)](https://black.readthedocs.io/)
[![ver](https://img.shields.io/badge/calver-YYYY.0M.MICRO-blue)](https://calver.org/)
[![log](https://img.shields.io/badge/change-log-informational)](https://gitlab.com/yaq/yaqd-control/-/blob/master/CHANGELOG.md)

Command line tools for inspecting and controlling yaq daemons.
https://control.yaq.fyi/
